@@ -8,13 +8,13 @@ use Carp;
 #===================================================================
 # $Author     : Djibril Ousmanou  and Laurent Rosenfeld            $
 # $Copyright  : 2015                                               $
-# $Update     : 24/08/2015                                         $
+# $Update     : 26/08/2015                                         $
 # $AIM        : Hyphenate words for French language                $
 #===================================================================
 use utf8;
 
 use vars qw / $VERSION /;
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 sub new {
 	my ( $self, $ref_arguments ) = @_;
@@ -1153,7 +1153,7 @@ __END__
 
 =head1 NAME
 
-Lingua::FR::Hyphen - hyphenates French words
+Lingua::FR::Hyphen - Hyphenate French words
 
 =head1 SYNOPSIS
 
@@ -1163,7 +1163,7 @@ Lingua::FR::Hyphen - hyphenates French words
     use Lingua::FR::Hyphen;
     use utf8;
       
-    binmode( STDOUT, ":utf8" );
+    binmode( STDOUT, ':utf8' );
     my $hyphenator = new Lingua::FR::Hyphen;
       
     foreach (qw/  
@@ -1174,17 +1174,17 @@ Lingua::FR::Hyphen - hyphenates French words
         print "$_ -> " . $hyphenator->hyphenate($_) . "\n";
     }
 
-    représentation -> repré-sen-ta-tion
-    Montpellier -> Montpellier
-    avocat -> avo-cat
-    porte-monnaie -> porte-monnaie
-    0102030405 -> 0102030405
-    rouge-gorge -> rouge-gorge
-    transaction -> tran-sac-tion
-    consultant -> consul-tant
-    rubicon -> rubicon
-    développement -> déve-lop-pe-ment
-    UNESCO -> UNESCO
+    # représentation -> repré-sen-ta-tion
+    # Montpellier -> Montpellier
+    # avocat -> avo-cat
+    # porte-monnaie -> porte-monnaie
+    # 0102030405 -> 0102030405
+    # rouge-gorge -> rouge-gorge
+    # transaction -> tran-sac-tion
+    # consultant -> consul-tant
+    # rubicon -> rubicon
+    # développement -> déve-lop-pe-ment
+    # UNESCO -> UNESCO
 
 =head1 DESCRIPTION
 
@@ -1272,12 +1272,11 @@ This module is based on the Knuth-Liang Algorithm. Frank Liang wrote his Stanfor
 Donald Knuth) on a hyphenation algorithm that was aimed at TeX (the typesetting utility written by Knuth) and is now standard in
 Tex, and has been adapted to many open source projects such as OpenOffice, LibreOffice, Firefox, Thunderbird, etc. His 1983 PhD thesis 
 can be found at L<http://www.tug.org/docs/liang/>. He invented both the "packed or compressed trie" structure for storing 
-
 efficiently the patterns and the way to represent possible hyphens in those patterns.
 
-This module is also partly derived from Alex Kapranoff's L<http://search.cpan.org/~kappa/Text-Hyphen-0.11/lib/Text/Hyphen.pm> module to hyphenate English language words.
+This module is also partly derived from Alex Kapranoff's L<Text::Hyphen> module to hyphenate English language words.
 
-The list of hyphenation patterns for the French language was derived from the Dicollecte site 
+The list of hyphenation (« césure » or « coupure de mots » in French) patterns for the French language was derived from the Dicollecte site 
 (L<http://www.dicollecte.org/home.php?prj=fr>), which produces several French open source 
 spell check dictionaries, used notably for Latex, OpenOffice and LibreOffice. The list of 
 patterns itself can be found there: L<http://www.dicollecte.org/download/fr/hyph-fr-v3.0.zip>.
